{% extends "theme_bootstrap/subnav_base.html" %}
{% comment %}
This file is here for backwards compatibility.  Please update your
templates to extend the theme_bootstrap/subnav_base.html file instead.
{% endcomment %}
