{% for message in messages %}
    <div class="alert fade in {% if message.tags %} alert-{{ message.tags }}{% endif %}">
        <button type="button" class="close" data-dismiss="alert">&times;</button>
        {{ message }}
    </div>
{% endfor %}
