{% extends "site_base.html" %}

{% load i18n %}

{% block body_base %}
    <div class="container">
        {% include "_messages.html" %}
        <div class="row">
            <div class="col-lg-2 columns">
                {% block subnav %}
                {% endblock %}
            </div>
            <div class="col-lg-10 columns">
                {% block body %}
                {% endblock %}
            </div>
        </div>
    </div>
{% endblock %}